| Title: | Neutrosophic Analysis of Completely Randomized Designs and Randomized Complete Block Designs |
|---|---|
| Description: | Provides neutrosophic analysis of variance (NANOVA) and analysis of covariance (NANCOVA) for Completely Randomized Designs (CRD) and Randomized Complete Block Designs (RCBD) using interval-valued observations. Computes interval sums of squares, mean squares, F-statistics, significance tests, and interval-based least significant difference (LSD) comparisons. When lower and upper observations are identical (crisp data), the methods reduce to the corresponding classical ANOVA and ANCOVA. |
| Authors: | Neethu R.S. [aut, ctb], Boyina Devi Priyanka [aut, ctb], Cini Varghese [aut, ctb], Mohd Harun [aut, ctb], Anindita Datta [aut, ctb], Vinaykumar L.N. [aut, cre] |
| Maintainer: | Vinaykumar L.N. <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.1 |
| Built: | 2026-07-22 12:22:55 UTC |
| Source: | https://github.com/cran/NeutroCrdRcbdAnalysis |
Performs Neutrosophic Analysis of Covariance (NANCOVA) for interval-valued response and covariate data from a Completely Randomized Design (CRD).
CRDnsANCOVA( Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = FALSE )CRDnsANCOVA( Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = FALSE )
Lower_y |
Numeric matrix of lower bounds of the response variable. |
Upper_y |
Numeric matrix of upper bounds of the response variable. |
Lower_z |
Numeric matrix of lower bounds of the covariate. |
Upper_z |
Numeric matrix of upper bounds of the covariate. |
design |
Numeric matrix representing the CRD treatment layout. |
alpha |
Significance level for interval-based LSD comparisons. Default is 0.05. |
verbose |
Logical. If |
A list containing the Neutrosophic ANCOVA table, interval LSD comparisons (if treatment effects are significant), and the interval LSD value.
Lower_y <- matrix(c( 20,25,30,35, 21,26,31,36, 19,24,29,34, 20,25,30,35, 21,26,31,36 ), nrow = 5, byrow = TRUE) Upper_y <- matrix(c( 22,27,32,37, 23,28,33,38, 21,26,31,36, 22,27,32,37, 23,28,33,38 ), nrow = 5, byrow = TRUE) Lower_z <- matrix(c( 8,9,10,11, 9,10,11,12, 8,9,10,11, 9,10,11,12, 8,9,10,11 ), nrow = 5, byrow = TRUE) Upper_z <- matrix(c( 9,10,11,12, 10,11,12,13, 9,10,11,12, 10,11,12,13, 9,10,11,12 ), nrow = 5, byrow = TRUE) design <- matrix(c( 1,2,3,4, 1,2,3,4, 1,2,3,4, 1,2,3,4, 1,2,3,4 ), nrow = 5, byrow = TRUE) CRDnsANCOVA(Lower_y, Upper_y, Lower_z, Upper_z, design)Lower_y <- matrix(c( 20,25,30,35, 21,26,31,36, 19,24,29,34, 20,25,30,35, 21,26,31,36 ), nrow = 5, byrow = TRUE) Upper_y <- matrix(c( 22,27,32,37, 23,28,33,38, 21,26,31,36, 22,27,32,37, 23,28,33,38 ), nrow = 5, byrow = TRUE) Lower_z <- matrix(c( 8,9,10,11, 9,10,11,12, 8,9,10,11, 9,10,11,12, 8,9,10,11 ), nrow = 5, byrow = TRUE) Upper_z <- matrix(c( 9,10,11,12, 10,11,12,13, 9,10,11,12, 10,11,12,13, 9,10,11,12 ), nrow = 5, byrow = TRUE) design <- matrix(c( 1,2,3,4, 1,2,3,4, 1,2,3,4, 1,2,3,4, 1,2,3,4 ), nrow = 5, byrow = TRUE) CRDnsANCOVA(Lower_y, Upper_y, Lower_z, Upper_z, design)
Performs neutrosophic analysis of variance (NANOVA) for a completely randomized design using interval-valued observations.
CRDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)CRDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)
Lower_y |
Matrix of lower bounds of the response variable. |
Upper_y |
Matrix of upper bounds of the response variable. |
design |
Matrix specifying treatment allocation. |
alpha |
Significance level for LSD test. |
verbose |
Logical. If TRUE, prints the analysis. |
A list containing the NANOVA table, treatment means, pairwise comparisons, and LSD interval.
Lower_y <- matrix(c( 9.5, 19.5, 29.5, 39.5, 10.0, 20.0, 30.0, 40.0, 10.5, 20.5, 30.5, 40.5, 9.8, 19.8, 29.8, 39.8, 10.2, 20.2, 30.2, 40.2 ), nrow = 5, byrow = TRUE) Upper_y <- matrix(c( 10.5, 20.5, 30.5, 40.5, 11.0, 21.0, 31.0, 41.0, 11.5, 21.5, 31.5, 41.5, 10.8, 20.8, 30.8, 40.8, 11.2, 21.2, 31.2, 41.2 ), nrow = 5, byrow = TRUE) design <- matrix(c( 1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4 ), nrow = 5, byrow = TRUE) CRDnsANOVA( Lower_y = Lower_y, Upper_y = Upper_y, design = design, alpha = 0.05, verbose = TRUE )Lower_y <- matrix(c( 9.5, 19.5, 29.5, 39.5, 10.0, 20.0, 30.0, 40.0, 10.5, 20.5, 30.5, 40.5, 9.8, 19.8, 29.8, 39.8, 10.2, 20.2, 30.2, 40.2 ), nrow = 5, byrow = TRUE) Upper_y <- matrix(c( 10.5, 20.5, 30.5, 40.5, 11.0, 21.0, 31.0, 41.0, 11.5, 21.5, 31.5, 41.5, 10.8, 20.8, 30.8, 40.8, 11.2, 21.2, 31.2, 41.2 ), nrow = 5, byrow = TRUE) design <- matrix(c( 1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4 ), nrow = 5, byrow = TRUE) CRDnsANOVA( Lower_y = Lower_y, Upper_y = Upper_y, design = design, alpha = 0.05, verbose = TRUE )
Performs neutrosophic analysis of covariance for a Randomized Complete Block Design using interval-valued response and covariate data.
RCBDnsANCOVA( Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = FALSE )RCBDnsANCOVA( Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = FALSE )
Lower_y |
Numeric matrix of lower response values. |
Upper_y |
Numeric matrix of upper response values. |
Lower_z |
Numeric matrix of lower covariate values. |
Upper_z |
Numeric matrix of upper covariate values. |
design |
Numeric matrix representing the RCBD layout. |
alpha |
Significance level for LSD test. Default is |
verbose |
Logical; if |
A list containing the NANCOVA table, LSD interval, and treatment comparisons (if treatment effect is significant).
Lower_y <- matrix(c( 46.84, 97.69, 39.30, 49.20, 51.52, 83.38, 56.48, 42.15, 44.42, 49.64, 44.21, 35.79, 32.77, 74.30, 55.72, 70.55 ), nrow = 4, byrow = TRUE) Upper_y <- matrix(c( 49.66,101.31,47.70,55.80, 60.98,87.62,60.52,44.85, 52.26,59.36,52.79,44.61, 42.23,82.70,59.28,75.45 ), nrow = 4, byrow = TRUE) Lower_z <- matrix(c( 224.95,245.87,245.19,259.41, 222.06,213.83,253.10,247.51, 255.67,230.55,265.05,246.67, 137.98,214.68,251.49,257.70 ), nrow = 4, byrow = TRUE) Upper_z <- matrix(c( 229.05,250.13,252.81,268.59, 229.94,222.17,258.90,256.49, 262.33,237.45,274.95,249.33, 142.02,219.32,260.51,264.30 ), nrow = 4, byrow = TRUE) design <- matrix(c( 1,2,3,4, 1,2,3,4, 1,2,3,4, 1,2,3,4 ), nrow = 4, byrow = TRUE) result <- RCBDnsANCOVA( Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = TRUE )Lower_y <- matrix(c( 46.84, 97.69, 39.30, 49.20, 51.52, 83.38, 56.48, 42.15, 44.42, 49.64, 44.21, 35.79, 32.77, 74.30, 55.72, 70.55 ), nrow = 4, byrow = TRUE) Upper_y <- matrix(c( 49.66,101.31,47.70,55.80, 60.98,87.62,60.52,44.85, 52.26,59.36,52.79,44.61, 42.23,82.70,59.28,75.45 ), nrow = 4, byrow = TRUE) Lower_z <- matrix(c( 224.95,245.87,245.19,259.41, 222.06,213.83,253.10,247.51, 255.67,230.55,265.05,246.67, 137.98,214.68,251.49,257.70 ), nrow = 4, byrow = TRUE) Upper_z <- matrix(c( 229.05,250.13,252.81,268.59, 229.94,222.17,258.90,256.49, 262.33,237.45,274.95,249.33, 142.02,219.32,260.51,264.30 ), nrow = 4, byrow = TRUE) design <- matrix(c( 1,2,3,4, 1,2,3,4, 1,2,3,4, 1,2,3,4 ), nrow = 4, byrow = TRUE) result <- RCBDnsANCOVA( Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = TRUE )
Performs Neutrosophic Analysis of Variance (NANOVA) for interval-valued response data from a Randomized Complete Block Design (RCBD).
RCBDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)RCBDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)
Lower_y |
Numeric matrix of lower bounds of the response variable. |
Upper_y |
Numeric matrix of upper bounds of the response variable. |
design |
Numeric matrix representing the RCBD layout. |
alpha |
Significance level for interval-based LSD test. Default is 0.05. |
verbose |
Logical. If |
A list containing the Neutrosophic ANOVA table, interval-based LSD comparisons (if applicable), and the interval LSD.
Lower_y <- matrix(c( 120.230,125.488,132.987,127.086,127.672,128.013, 122.594,121.009,123.969,120.358,120.424,122.197, 121.183,130.671,128.794,114.863,122.595,122.073, 127.620,124.532,132.893,125.528,125.850,127.550 ), nrow = 4, byrow = TRUE) Upper_y <- matrix(c( 127.6967536,131.2116955,141.2127373,136.1540904,130.6884772,136.8474149, 129.8264289,130.3314544,133.3113414,126.5063118,128.4362999,130.2714433, 124.5068016,139.3287297,134.1060197,124.2774447,127.2248520,130.3948469, 131.0638721,129.8884785,135.5666716,127.7580663,132.0178679,133.3903886 ), nrow = 4, byrow = TRUE) design <- matrix(c( 1,2,3,4,5,6, 1,2,3,4,5,6, 1,2,3,4,5,6, 1,2,3,4,5,6 ), nrow = 4, byrow = TRUE) RCBDnsANOVA(Lower_y, Upper_y, design)Lower_y <- matrix(c( 120.230,125.488,132.987,127.086,127.672,128.013, 122.594,121.009,123.969,120.358,120.424,122.197, 121.183,130.671,128.794,114.863,122.595,122.073, 127.620,124.532,132.893,125.528,125.850,127.550 ), nrow = 4, byrow = TRUE) Upper_y <- matrix(c( 127.6967536,131.2116955,141.2127373,136.1540904,130.6884772,136.8474149, 129.8264289,130.3314544,133.3113414,126.5063118,128.4362999,130.2714433, 124.5068016,139.3287297,134.1060197,124.2774447,127.2248520,130.3948469, 131.0638721,129.8884785,135.5666716,127.7580663,132.0178679,133.3903886 ), nrow = 4, byrow = TRUE) design <- matrix(c( 1,2,3,4,5,6, 1,2,3,4,5,6, 1,2,3,4,5,6, 1,2,3,4,5,6 ), nrow = 4, byrow = TRUE) RCBDnsANOVA(Lower_y, Upper_y, design)